summaryrefslogtreecommitdiffstats
path: root/smb4k/searchdlg/smb4ksearchdialog_part.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/searchdlg/smb4ksearchdialog_part.h')
-rw-r--r--smb4k/searchdlg/smb4ksearchdialog_part.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/smb4k/searchdlg/smb4ksearchdialog_part.h b/smb4k/searchdlg/smb4ksearchdialog_part.h
index 38e97b9..633b217 100644
--- a/smb4k/searchdlg/smb4ksearchdialog_part.h
+++ b/smb4k/searchdlg/smb4ksearchdialog_part.h
@@ -58,7 +58,7 @@ class Smb4KSearchDialogPart : public KParts::Part
/**
* The constructor.
*
* @param tqparentWidget The tqparent widget
*
* @param widgetName The name the widget should have
*
@@ -66,7 +66,7 @@ class Smb4KSearchDialogPart : public KParts::Part
*
* @param name The name this object should have
*/
- Smb4KSearchDialogPart( TQWidget *tqparentWidget = 0, const char *widgetName = 0,
+ Smb4KSearchDialogPart( TQWidget *parentWidget = 0, const char *widgetName = 0,
TQObject *tqparent = 0, const char *name = 0 );
/**
@@ -149,7 +149,7 @@ class Smb4KSearchDialogPartFactory : public KParts::Factory
/**
* Reimplemented from KParts::Factory
*/
- virtual KParts::Part *createPartObject( TQWidget *tqparentWidget, const char *widgetName,
+ virtual KParts::Part *createPartObject( TQWidget *parentWidget, const char *widgetName,
TQObject *tqparent, const char *name,
const char *classname, const TQStringList &args );
@@ -58,7 +58,7 @@ class Smb4KSearchDialogPart : public KParts::Part
* The constructor.
*
- * @param tqparentWidget The tqparent widget
+ * @param parentWidget The tqparent widget
*
* @param widgetName The name the widget should have